.. _const:

Constants
=========

Contains various constants related to the environment of the container.

Example usage::

    from os.path import join
    from derivermodule.const import PB_ITEM

    test_txt_in_item = join(PB_ITEM, 'test.txt')


.. automodule:: derivermodule.const
    :members:
